@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 
 from django.shortcuts import get_object_or_404
 from django.views.generic.detail import DetailView
@@ -8,7 +9,7 @@ from meta.views import MetadataMixin
 
 
 class MetaTagsMexin(MetadataMixin):
-    """ Mixin для отображения meta тегов из батарейки django-meta """
+    """ Mixin for show meta tegs from django-meta """
 
     def get_meta_description(self, context):
         return self.page.meta_description
@@ -33,7 +34,7 @@ class HomePageView(MetaTagsMexin, DetailView):
         return context
 
     def get_object(self):
-        page = get_object_or_404(Page, slug='home')
+        page = get_object_or_404(self.model, slug='home')
         self.page = page
         return page
 
@@ -45,7 +46,7 @@ class PageDetailView(MetaTagsMexin, DetailView):
     template_name = 'page/default.html'
 
     def get_object(self):
-        page = get_object_or_404(Page, path=self.request.path, active=1)
+        page = get_object_or_404(self.model, path=self.request.path, active=1)
         self.page = page
         return page
 
